﻿using System;
using System.Drawing;
using System.Windows.Forms;

using DevExpress.XtraSplashScreen;

namespace TestProject
{
    /// <summary>
    /// 커스텀 오버레이 이미지 페인터
    /// </summary>
    public class CustomOverlayImagePainter : OverlayImagePainter
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 소유자 컨트롤
        /// </summary>
        private Control ownerControl;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - CustomOverlayImagePainter(ownerControl, image, hoverImage, Action)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="ownerControl">소유자 컨트롤</param>
        /// <param name="image">이미지</param>
        /// <param name="hoverImage">호버 이미지</param>
        /// <param name="clickAction">클릭 액션</param>
        public CustomOverlayImagePainter(Control ownerControl, Image image, Image hoverImage = null, Action clickAction = null) : base
        (
            image,
            hoverImage,
            clickAction
        )
        {
            this.ownerControl = ownerControl;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 이미지 경계 계산하기 - CalcImageBounds(e)

        /// <summary>
        /// 이미지 경계 계산하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        /// <returns>이미지 경계</returns>
        protected override Rectangle CalcImageBounds(OverlayLayeredWindowObjectInfoArgs e)
        {
            Rectangle imageRectangle = new Rectangle
            (
                (this.ownerControl.ClientRectangle.Width  - Image.Width ) / 2,
                (this.ownerControl.ClientRectangle.Height - Image.Height) / 2 - e.ImageBounds.Height,
                Image.Width,
                Image.Height
            );

            return imageRectangle;
        }

        #endregion
    }
}