﻿using System.Drawing;
using System.Windows.Forms;

using DevExpress.XtraSplashScreen;

namespace TestProject
{
    /// <summary>
    /// 커스텀 오버레이 텍스트 페인터
    /// </summary>
    public class CustomOverlayTextPainter : OverlayTextPainter
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 소유자 컨트롤
        /// </summary>
        private Control ownerControl;

        /// <summary>
        /// 텍스트 오프셋
        /// </summary>
        private int textOffsetY;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - CustomOverlayTextPainter(ownerControl, font, color, textOffsetY)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="ownerControl">소유자 컨트롤</param>
        /// <param name="font">폰트</param>
        /// <param name="color">색상</param>
        /// <param name="textOffsetY">텍스트 오프셋</param>
        public CustomOverlayTextPainter(Control ownerControl, Font font, Color color, int textOffsetY) : base()
        {
            this.ownerControl = ownerControl;

            Font  = font;
            Color = color;

            this.textOffsetY = textOffsetY;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 텍스트 경계 계산하기 - CalcTextBounds(e)

        /// <summary>
        /// 텍스트 경계 계산하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        /// <returns>텍스트 경계</returns>
        protected override Rectangle CalcTextBounds(OverlayLayeredWindowObjectInfoArgs e)
        {
            using(Graphics graphics = this.ownerControl.CreateGraphics())
            {
                Size textSize = graphics.MeasureString(Text, Font).ToSize();

                Rectangle textRectangle = new Rectangle
                (
                    (this.ownerControl.ClientRectangle.Width  - textSize.Width ) / 2,
                    (this.ownerControl.ClientRectangle.Height - textSize.Height) / 2 + this.textOffsetY,
                    textSize.Width,
                    textSize.Height
                );

                return textRectangle;
            }
        }

        #endregion
    }
}